{
  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs";
    fenix.url = "github:nix-community/fenix";
  };

  outputs = { self, nixpkgs, flake-utils, fenix }:
    flake-utils.lib.eachDefaultSystem (system:
      let
        pkgs = import nixpkgs {
          inherit system;
          overlays = [ fenix.overlays.default ];
        };

        toolchain = pkgs.fenix.stable;

        flakePkgs = rec { cordial = pkgs.callPackage ./. { }; };
      in rec {
        devShell = pkgs.mkShell {
          inputsFrom = with flakePkgs; [ cordial ];

          packages = (with pkgs; [
            cmake
            ninja

            elixir
            inotify-tools

            cargo-deny
            cargo-edit
            cargo-expand
            cargo-flamegraph
            cargo-watch

          ]) ++ (with toolchain; [
            cargo
            rustc
            clippy

            # Get the nightly version of rustfmt so we can wrap comments
            pkgs.fenix.default.rustfmt
          ]);

          CARGO_UNSTABLE_SPARSE_REGISTRY = "true";
        };
      });
}
